<div>
<img src="examples/boothy.png" alt="Boothy" width="2000" height="240" align="center"
</div>



# Boothy

Boothy is an Open Source bootstrap hypothesis library that can help you evaluate different types of hypothesis tests. The aim of boothy is to give an easy way to perform an hypothesis test and interpretation of results.
Booty is under development, and any suggestions are welcome.

## Getting Started

To get started install the boothy library using pip and run the Jupyter notebook example in the examples folder.

### Prerequisites

The following packages are required to install boothy:

* Numpy 1.23.5

* Matplotlib 3.5.1

* Seaborn 0.12.1



### Installing

To install boothy in the terminal run

    pip install boothy

## Versioning

We use [Semantic Versioning](http://semver.org/) for versioning. Current version is 0.1.0

## Authors

- **Manuel Rios**
  
   [Github](https://github.com/mriosrivas)

## License

This project is licensed under MIT licence.
